==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtselstrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "selection by string matching"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "key attribute"
#define KEYC "key attribute (if omitted, all line are assumed to take the distinct key value)"

/*-f*/
#define FLDT "a list of attributes"
#define FLDC "a list of attributes for which you want to search"
#define FLDF NULL

/*-v*/
#define VALT "list of character strings searched for"
#define VALC "a list of character strings  for which you want to search the attributes specified by -f"

/*-F*/
#define ANDT "'AND' condition between attributes"
#define ANDC "When more than one attribute is specified by -f, the line is selected (or deleted) only if every attribute contains the matched string."

/*-R*/
#define ARCT "'AND' condition between records"
#define ARCC "When a key is specified by -k, selection (or deletion) is done only if all the lines corresponding to the key satisfy the condition."

/*-r*/
#define REVT "reverse condition"
#define REVC "Deletion is done instead of selection."

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " For an attribute specified by -f, if it contains one of strings specified by -v, the corresponding line is selected (or deleted)."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtselstr -f article -v cola,chocolate -i dat.xt -o rsl.xt\n\
xtselstr -k customerID -f article -v cola,chocolate -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtcommon"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/en/xtselstrHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "selection by string matching"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "key attribute"
#define KEYC "key attribute (if omitted, all line are assumed to take the distinct key value)"

/*-f*/
#define FLDT "a list of attributes"
#define FLDC "a list of attributes for which you want to search"
#define FLDF NULL

/*-v*/
#define VALT "list of character strings searched for"
#define VALC "a list of character strings  for which you want to search the attributes specified by -f"

/*-F*/
#define ANDT "'AND' condition between attributes"
#define ANDC "When more than one attribute is specified by -f, the line is selected (or deleted) only if every attribute contains the matched string."

/*-R*/
#define ARCT "'AND' condition between records"
#define ARCC "When a key is specified by -k, selection (or deletion) is done only if all the lines corresponding to the key satisfy the condition."

/*-r*/
#define REVT "reverse condition"
#define REVC "Deletion is done instead of selection."

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " Select the record where the search string matches the corresponding attribute defined in -f. Multiple character strings can be defined delimited by comma. Yet, xtcommon is preferred when there are too many strings. Searching is done by storing a set of character strings in a hash table. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtselstr -f article -v cola,chocolate -i dat.xt -o rsl.xt\n\
xtselstr -k customerID -f article -v cola,chocolate -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtcommon"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
